Learn R Programming

cystiSim (version 0.1.0)

do_pig_mda_vac: Do pig mass drug administration (MDA) and vaccination

Description

Intervention function that mimics the possible effects of combined pig mass drug administration and vaccination.

Usage

do_pig_mda_vac(x, coverage, efficacy.mda, efficacy.vac, immunity.mda = 3, immunity.vac = Inf, interval = 4, min.age = 1, max.age = Inf)

Arguments

x
cystiRun object.
coverage
Presumed coverage within eligible population, expressed as a decimal value.
efficacy.mda
Presumed efficacy of drug treatment, expressed as a decimal value.
efficacy.vac
Presumed efficacy of vaccine, expressed as a decimal value.
immunity.mda
Presumed duration of immunity following drug treatment of an infected pig. Defaults to 3 months.
immunity.vac
Presumed duration of immunity following successful vaccination. Defaults to Inf.
interval
Maximum interval between two consecutive shots for immunity. Defaults to 4 months.
min.age
Minimum age for intervention, in months. Defaults to 1 month.
max.age
Maximum age for intervention, in months. Defaults to Inf, i.e., no upper age limit.

See Also

Other interventions: do_man_mda, do_pig_mda, do_pig_vac