Learn R Programming

cystiSim (version 0.1.0)

do_pig_vac: Do pig vaccination

Description

Intervention function that mimics the possible effects of pig vaccination.

Usage

do_pig_vac(x, coverage, efficacy, immunity = Inf, interval = 4, min.age = 1, max.age = Inf)

Arguments

x
cystiRun object.
coverage
Presumed coverage of vaccination within eligible population, expressed as a decimal value.
efficacy
Presumed efficacy of vaccine, expressed as a decimal value.
immunity
Presumed duration of immunity following successful vaccination. Defaults to Inf.
interval
Maximum interval between two consecutive shots for immunity. Defaults to 4 months.
min.age
Minimum age for vaccination, in months. Defaults to 1 month.
max.age
Maximum age for vaccination, in months. Defaults to Inf, i.e., no upper age limit.

See Also

Other interventions: do_man_mda, do_pig_mda, do_pig_mda_vac